/*
Midbar
Distributed under the MIT License
© Copyright Maxim Bortnikov 2022
For more information please visit
https://sourceforge.net/projects/midbar/
https://osdn.net/projects/midbar/
https://github.com/Northstrix/Midbar
Required libraries:
https://github.com/zhouyangchao/AES
https://github.com/peterferrie/serpent
https://github.com/ddokkaebi/Blowfish
https://github.com/Northstrix/DES_and_3DES_Library_for_MCUs
https://github.com/ulwanski/sha512
https://github.com/adafruit/Adafruit-GFX-Library
https://github.com/adafruit/Adafruit-SSD1351-library
https://github.com/adafruit/Adafruit_BusIO
https://github.com/GyverLibs/GyverBus
https://github.com/PaulStoffregen/PS2Keyboard
https://github.com/siara-cc/esp32_arduino_sqlite3_lib
https://github.com/intrbiz/arduino-crypto
https://github.com/GyverLibs/EncButton
https://github.com/Chris--A/Keypad
https://github.com/platisd/nokia-5110-lcd-library
*/
/*************************************************** 
  This is a example sketch demonstrating graphic drawing
  capabilities of the SSD1351 library for the 1.5" 
  and 1.27" 16-bit Color OLEDs with SSD1351 driver chip
  Pick one up today in the adafruit shop!
  ------> http://www.adafruit.com/products/1431
  ------> http://www.adafruit.com/products/1673
 
  If you're using a 1.27" OLED, change SCREEN_HEIGHT to 96 instead of 128.
  These displays use SPI to communicate, 4 or 5 pins are required to  
  interface
  Adafruit invests time and resources providing this open source code, 
  please support Adafruit and open-source hardware by purchasing 
  products from Adafruit!
  Written by Limor Fried/Ladyada for Adafruit Industries.  
  BSD license, all text above must be included in any redistribution
  The Adafruit GFX Graphics core library is also required
  https://github.com/adafruit/Adafruit-GFX-Library
  Be sure to install it!
 ****************************************************/

// Screen dimensions
#define SCREEN_WIDTH  128
#define SCREEN_HEIGHT 128 // Change this to 96 for 1.27" OLED.

// You can use any (4 or) 5 pins 
// ESP32

#define SCLK_PIN 18
#define MOSI_PIN 23
#define DC_PIN   2
#define CS_PIN   15
#define RST_PIN  4

// ESP8266
/*
#define SCLK_PIN D5
#define MOSI_PIN D7
#define DC_PIN   D4
#define CS_PIN   D8
#define RST_PIN  D6
*/

#include <Adafruit_GFX.h>
#include <Adafruit_SSD1351.h>
#include <SPI.h>

// Option 1: use any pins but a little slower
//Adafruit_SSD1351 tft = Adafruit_SSD1351(SCREEN_WIDTH, SCREEN_HEIGHT, CS_PIN, DC_PIN, MOSI_PIN, SCLK_PIN, RST_PIN);  

// Option 2: must use the hardware SPI pins 
// (for UNO thats sclk = 13 and sid = 11) and pin 10 must be 
// an output. This is much faster - also required if you want
// to use the microSD card (see the image drawing example)
Adafruit_SSD1351 oled = Adafruit_SSD1351(SCREEN_WIDTH, SCREEN_HEIGHT, &SPI, CS_PIN, DC_PIN, RST_PIN);

const uint16_t conv_to_565_img [128][129] = {
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4225,4161,4225,6273,6273,6273,6273,6273,12612,10499,14627,23013,14594,18721,18721,18753,22881,14561,4128,4128,0,0,8321,2048,4128,4160,0,0,0,2048,4160,6208,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6274,4193,6273,8353,25190,6273,6306,6273,6273,6273,12547,20900,16674,18721,18721,18721,18721,16641,8288,2048,0,0,0,0,2048,2048,6240,2080,0,2048,4160,6240,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6307,4259,4259,4259,18919,16806,16806,33676,18918,14725,14725,8451,10532,14725,14725,14693,12612,14693,14725,16773,14692,14692,14692,14693,14692,14725,18886,18918,14725,16805,18886,18886,12579,16740,8354,6273,6273,6273,6273,6273,6273,6273,12547,20900,16641,18721,18721,20801,27041,24993,10400,6208,4128,0,0,0,4128,4160,4128,2048,2048,2048,4160,4128,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18661,37221,4226,4226,4226,4258,18918,16806,16805,31530,20999,16805,16805,16805,8419,14725,16805,16805,14725,16805,18885,18885,16805,16772,16805,16805,16805,25191,23110,21030,18885,18885,27304,27271,25126,27141,14562,6273,8354,4225,10434,6273,6273,6273,12546,20867,20801,20801,22849,20801,20801,16609,10400,6208,4128,0,4128,2080,4128,4128,4160,2048,2048,4096,4160,6240,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8355,4226,4226,4226,6339,27272,18886,16773,14725,18886,14725,23111,29385,14660,6306,10467,14693,12580,14692,18821,18853,20933,14660,16773,16773,14660,27271,18853,16772,16740,14660,18821,20901,24996,51845,39201,8321,6305,4225,16772,10499,6273,6273,12547,22947,27009,24929,24961,24961,27009,27009,27009,16608,4128,2048,4096,2048,4128,4128,4128,4160,2048,2048,4128,4160,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14565,14597,8387,4226,4226,4226,8419,27272,14725,14693,14693,12580,16773,18853,23079,18886,10499,10467,14692,16773,21033,29223,27174,31400,27272,33609,31433,29385,39884,31497,33578,35659,33577,27207,27142,31302,47685,30978,8321,4193,6273,4225,6273,6273,6273,12547,22947,27009,24929,24929,27009,29089,27009,18688,14496,2048,2048,4128,2048,4096,4128,4128,4128,2048,2048,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24805,45413,43527,25096,14693,8387,8387,14661,29353,23080,27338,27338,27338,31531,33611,39885,31531,25160,10467,12547,23015,31305,49768,43688,35528,37804,44173,39916,39950,46320,37869,37902,37804,31465,23014,25029,27142,27077,20835,14594,10434,12546,14627,14627,14627,14594,16707,18787,24961,24929,24961,24961,29089,27041,22849,22849,6208,2080,6208,6240,4160,2048,4096,4096,0,0,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,41285,60167,41675,44666,29582,12548,12548,25225,27273,25193,33644,33612,50709,33611,31531,33644,31499,20999,16740,12547,25256,37483,60363,47718,29255,35756,39883,31497,31530,44175,33676,31498,31530,29352,23046,27174,29255,27174,20867,14594,14594,14594,18820,16675,18788,18788,18819,20900,22947,33381,33381,33348,33348,31235,29154,29154,6208,4128,4096,4128,4160,4128,2080,2080,2080,4128,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37318,35044,29388,40343,21162,6307,4226,27403,29385,20999,23112,29417,35756,25192,27305,35691,27305,23079,20966,16773,25192,22917,43623,37511,35561,35724,39916,35691,35756,48466,35821,33643,33578,25126,23014,22981,23014,20868,20868,14626,14626,14594,14626,16674,16707,16707,20867,18787,20867,31301,31301,33349,33381,29187,22914,24994,6208,2080,2048,4096,4160,2048,4160,4128,4128,4128,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16613,47654,12581,6371,4258,4226,23178,29386,14693,25192,42062,12580,12612,20966,25159,18853,39883,23079,18886,12776,16740,20933,27206,31400,16805,25159,27272,23144,35756,29450,33611,31530,29385,27239,29287,29254,33479,14627,6305,6273,8353,6305,8354,10434,14626,14626,12546,20867,31301,27107,27107,29187,27075,12449,8288,4128,4128,4096,4193,4160,0,4160,4128,4096,2048,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12516,6275,4226,4226,6307,12645,29386,21032,33709,42095,33643,18919,20999,27272,35658,41997,25192,20999,23112,10499,33577,25125,31464,27272,31464,29319,23079,42062,25159,25158,25127,27337,27239,25158,27239,29319,16739,12514,12514,12546,12546,14594,14627,14626,16707,6273,20867,31301,31301,33413,37574,37574,27075,20834,4160,6209,6208,4225,4225,2048,4160,4128,4096,4160,4160,4096,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4194,8419,8419,6307,10500,27306,20999,31531,44110,39917,20999,23079,35658,42029,31465,25192,20999,20999,20999,23046,25159,20965,20966,35657,29319,25127,42029,23078,23046,23078,20934,25191,23078,25159,31464,18820,14594,16740,16675,20901,16707,18787,18788,18787,16707,20868,31301,31301,33381,35494,37574,35428,16641,4096,6241,6208,12807,8419,4128,12611,4128,4128,4160,4160,2080,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4226,4226,4226,6307,10500,27306,20999,35756,44174,37869,20999,20999,25192,31497,35723,31530,29385,21031,20966,16773,18885,33577,12612,31464,27271,23046,37770,20966,23046,23078,20965,31497,25191,25159,25190,18820,14594,14594,14626,16707,14627,16707,16707,18787,20899,20867,29253,29221,33382,35494,33414,29188,33348,6240,6208,8289,17033,8451,4128,8353,4160,4096,4128,4128,4128,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4194,4226,4226,6307,10500,27305,20999,33611,44175,42127,20999,20967,20999,25192,33545,27272,20999,18886,21031,20967,14692,33610,14692,20965,25126,20966,39916,29416,33577,31432,20966,35723,27271,27239,31464,23045,20965,18884,23045,20997,20965,25159,18885,25126,23046,18819,29221,24995,27108,31333,20867,6240,24994,4160,4160,6208,4128,4096,2048,8385,4160,4128,4128,4128,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18628,4194,4226,6306,29383,10532,27273,21032,31531,44142,33611,18919,18919,18918,31465,37804,27272,18918,21031,20999,25257,25192,16804,18853,18885,16772,18885,42029,35754,33577,27303,16805,20998,20966,25126,35755,33578,33609,29383,35721,35755,33642,35756,25224,27337,27304,20868,29253,27140,29221,25027,24995,18721,12481,6208,8321,4160,4128,2048,2048,18917,10401,4096,4128,4096,4160,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,43429,6242,4226,6306,33575,12645,25225,33709,37869,42094,44209,20999,20999,20966,27304,29385,25160,18886,20999,25388,33741,27304,25159,12580,27304,16772,18885,41996,33609,27303,20965,16805,27336,21031,20966,20998,25191,33674,29384,37835,31528,31529,44142,25224,25191,25159,22948,27141,29253,33414,35494,31301,27107,14561,6208,8321,6240,4160,0,4128,25223,6240,2048,4128,4128,4128,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6306,6306,8386,37735,14693,25193,25257,31498,39851,37868,31530,27272,23079,25159,39917,25159,18886,18919,35952,37999,27337,27272,10499,14692,18885,10499,33675,20965,18918,18853,16773,18917,16805,12612,10467,18885,23077,23078,27304,18885,23111,31530,18885,20999,14660,14594,14594,14594,16706,16706,12514,8353,8321,8385,8353,4160,4192,4193,6273,8385,6241,6241,6273,6241,6273,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,35237,18593,6306,6306,6306,12613,25193,35756,35724,42029,39850,31530,35657,31400,25127,41833,25127,18886,18918,38065,31661,29385,31497,23176,14659,10499,10467,18884,10499,8418,8418,8386,8386,8386,8386,6338,8386,10531,10499,8451,6306,8418,14692,6273,10433,6273,8353,6305,6305,8353,8353,6273,8353,8353,6305,6273,6305,8354,8386,8386,8418,8386,8386,8386,10466,10499,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18659,8290,8386,8386,4194,10532,25193,39982,31630,40015,41897,33611,35625,37672,25159,39785,29319,23111,18886,29549,31563,31465,31432,37901,27271,23078,23111,37835,18885,16805,16805,16773,16806,23018,18886,18918,20966,29417,25256,27402,23145,29385,35658,16740,35493,22915,20868,22948,25093,27173,29221,29253,37607,31300,20866,8320,4128,2048,2048,4128,14626,8288,4128,2048,2048,4160,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4226,4194,4226,2146,10500,25192,33611,25225,25225,44010,29417,29352,27304,40015,41898,29351,23079,18952,23210,27305,25224,27239,25224,31431,31496,29416,39980,18885,16773,16773,14693,14693,18885,18853,18853,23078,27304,25256,31628,31628,35691,37705,14627,33413,16642,16675,18787,16674,16674,16674,16674,25028,27107,10401,4128,4128,2048,4128,6240,10498,4128,4128,2048,4128,4160,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37253,6242,4226,2146,2146,8452,23144,29516,20999,18919,43978,31530,21031,25192,37934,33577,25159,16838,16838,25323,25224,25192,31465,16805,35689,39915,31465,31562,18885,18853,16805,14692,14724,18885,18853,16773,23078,35756,29418,33709,31597,33611,35724,12547,20866,20998,16707,22980,25060,25060,18786,14626,31333,31301,10401,4160,2048,2048,4128,4160,10400,6240,2048,2048,2080,4160,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28932,6242,2146,2146,4226,8452,23145,33907,23210,18919,23079,18919,18919,23112,25224,27304,20999,16838,16806,23242,21031,29384,31432,18853,39915,35722,25224,20997,16773,18853,18853,16772,16740,23110,18885,16805,20998,33610,31530,33709,29516,29450,31498,10499,20866,29417,12546,18819,23013,25061,20899,20931,33414,29253,20965,6273,4128,2048,2048,4128,4160,4128,2048,0,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12646,23145,23212,18984,18919,16838,14726,23112,29417,31498,35756,25191,16838,16806,14725,16806,23079,25191,27271,35657,31464,23079,31497,18886,14693,16773,14692,16773,20965,18885,18853,31399,41800,37705,31629,25290,25192,18918,12612,16706,23078,23045,10433,16674,20867,18787,16674,29254,27141,25224,8354,6208,4128,2048,2048,4160,4128,4128,0,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12646,14890,20966,35592,12579,8419,10532,12612,12612,31432,14692,8451,8484,6306,23078,23111,12711,10499,29415,25158,29351,46287,12580,8419,8419,8387,8419,12612,12580,14660,27173,39753,42062,29516,21096,14692,12611,6306,14593,29645,21030,8321,12514,18787,18786,12481,22947,31302,8353,6273,10369,4160,4096,4096,4128,2048,2080,2048,4128,4128,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27206,48203,42028,10500,10500,14692,14692,29384,12612,8419,8451,8387,12612,16805,16773,8419,10531,12580,18853,33577,10499,10499,10467,8419,8419,12579,18820,23013,50415,31366,25126,27370,18984,14692,12579,4225,12513,18885,8353,4160,6241,18754,20835,10433,16706,16707,2080,4160,8288,2048,2048,4128,4160,2080,2048,2048,2048,4128,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16773,33544,39882,16838,18918,27304,25192,27304,18886,16838,16838,23111,18886,20966,20999,18886,16806,16806,18918,33577,12612,14725,16838,16805,16805,18886,27174,25093,44011,29319,27305,31564,21032,14692,12644,4225,12513,10401,14594,6208,2048,10401,18754,10434,10401,14627,10434,2048,6208,4128,4128,4128,8418,4128,4128,0,2048,4128,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20999,39883,18918,18918,27304,29384,35756,25224,21031,16838,29385,20999,18918,18886,16806,16838,18886,18918,37803,18886,12612,16773,18886,16805,18886,23014,22981,37638,41996,42063,27371,21064,18918,16773,8419,18754,14561,12481,8320,6208,4128,4128,4128,4160,10434,8353,10434,14529,6208,4128,8321,23143,4160,4128,4096,2048,2080,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20999,42061,18886,18886,25192,27272,39916,29417,25224,18886,25224,25192,23111,21031,18886,25223,20999,23079,39948,20966,18886,10531,16838,18918,14692,23013,25028,43944,44077,46256,29450,21031,25192,29417,21031,18721,14561,14561,12448,10368,8288,8320,8321,2080,0,6240,18689,8320,4128,2048,2080,12643,8320,4160,4128,4128,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21031,42028,18886,18886,23112,29352,42029,25192,16870,18950,27272,44109,35658,27272,23079,39981,27304,29352,39883,33642,27304,16805,16773,16773,14692,20965,18787,23013,39883,44110,29385,25125,22947,27173,29318,22881,27009,18688,16608,12448,20736,8256,10400,12448,6208,2048,8288,4128,2048,0,2048,6272,6240,4128,4128,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10501,10533,10533,10533,10533,10533,10533,12614,12614,12614,10534,16839,23144,23112,20999,18886,16806,16773,14693,14693,12612,21031,37802,18918,20999,25192,23079,31497,23111,18918,27272,27304,48368,37803,27272,18918,27304,23111,25191,29417,44271,31530,25193,14725,16740,14627,18820,18787,18788,33545,39884,33579,16838,16773,14692,27500,23012,6208,6208,10368,10368,10336,8288,2048,4128,8288,4128,0,2048,2048,0,4128,10531,6240,4128,4128,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10533,10533,14758,16839,14758,18919,18920,18887,35690,21000,25161,12615,12614,21033,31530,33643,16773,16774,20998,29417,16805,12644,12612,14725,16805,12612,12612,14725,14692,12612,20966,18885,14692,20966,20998,16805,12612,12612,18886,23110,20998,27272,23078,18853,12612,10466,10434,12514,14594,16707,23012,25126,16806,10499,12547,10498,14725,12546,8321,10400,4128,6208,6208,8256,6176,4128,2048,2048,0,0,0,0,2048,6240,4128,2048,0,2048,4128,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10566,10533,12646,16839,31464,35690,20967,18920,37836,16808,18890,14631,14695,18887,18951,16838,12645,18918,33610,21031,14725,16773,14693,14693,16773,16773,12612,14692,14725,14725,20998,16805,12612,12580,14724,14725,12612,12612,16773,16772,14692,18853,18885,14627,12546,16739,18787,22915,20834,27140,39654,23013,27305,18853,20965,16805,25354,14724,6240,10433,10401,8288,4128,4128,4128,8256,4096,0,0,0,0,0,0,2080,2048,0,2048,2080,4128,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12614,10501,14726,23112,35691,35690,18887,16808,29357,14699,16813,16780,33646,23113,23112,18918,16806,20999,27272,23143,14725,18886,25191,18885,18886,20998,20998,14693,16805,14660,16805,16772,16773,14692,14724,14692,12612,16773,16740,14692,14692,14692,14692,14627,14594,18787,14561,31235,35395,41668,33348,29221,25093,14627,20933,18885,33806,21030,12513,8288,6208,18722,8320,8320,8288,12416,6208,2048,2048,0,0,0,0,0,0,0,0,2048,2080,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20740,22789,12613,10533,12613,12678,12646,12614,16775,14696,16781,12654,14701,14733,23148,16808,18919,20966,12613,14693,14693,10532,12612,18918,37803,23110,16805,12612,12612,14725,23110,14725,20965,18853,16805,14724,14692,12612,12580,14692,12612,14660,16772,14692,16773,14627,18787,22915,33315,39554,52066,47840,43747,39589,18787,20900,22979,25125,25289,27434,14627,6208,6208,10368,8288,8320,14528,16576,10400,4128,6176,2048,0,2048,0,0,2048,2048,2048,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18660,20741,10533,8420,8420,8484,8484,8419,6371,6371,10567,12651,8458,14929,10571,16839,21031,27369,12612,10500,10500,8419,14693,12612,16805,10531,8451,8419,8419,8419,12612,16838,10531,14692,10531,10499,10499,8419,8419,8419,10499,10499,10499,10499,12547,12579,14594,24962,37442,54177,54372,54338,54112,35362,20802,14593,20931,25157,19015,25419,14789,4128,6208,4128,4096,2048,4128,4096,6208,14496,10336,2048,2048,2048,2048,2080,4128,2048,2048,2048,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10436,12517,10533,6371,8419,10500,12645,18917,8451,10532,25262,25334,12657,12889,12757,31633,31498,25225,10532,10532,14693,16837,16773,23111,29449,14692,14692,12612,10500,12612,16837,12612,20997,25158,23078,20998,29384,12644,12612,10532,21030,16805,16805,12612,10499,10434,12514,20834,37442,54275,54669,54569,54144,33249,14561,16706,12545,25157,19015,12677,14757,4128,6208,4128,4128,4128,4128,4128,8320,8288,16576,4128,4096,4096,4128,14692,8288,4096,2048,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,35270,27112,10532,8419,14757,10532,10532,16773,14692,8419,16811,8559,10574,14867,12686,27372,25257,18951,12613,10500,16838,18918,31529,18885,20966,12644,12644,12612,10532,10499,12644,12580,12612,14692,16772,20998,35722,20966,16805,12644,12612,14692,16773,18885,12547,12547,18787,27107,35394,54211,56321,56256,54081,35329,20801,18786,16674,12513,23208,16870,6241,6208,4128,4096,2048,4096,4096,4128,6176,4096,6208,8256,4096,4096,4128,23176,16674,4096,4128,2048,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6308,10468,20968,10532,8419,33544,18853,20997,27238,27304,14692,14696,12585,12585,12720,12648,18952,27402,18919,12645,14758,16838,18918,29449,31530,18918,10532,10532,10532,10532,10500,12612,10532,10532,12612,14692,18917,16773,14692,16806,12612,12612,14692,16805,14660,12580,12580,14627,25092,29122,37442,41601,43648,35362,22881,12480,12513,10433,14626,14756,6305,4128,4128,18786,4128,4096,2048,4096,4128,6176,4128,6208,12384,4096,6176,4096,14692,6240,2048,4128,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6308,6340,23178,10532,8419,35624,20997,25157,35624,27303,12612,10565,10533,8453,10533,10533,10533,10565,18984,16838,25290,10565,12645,23143,27370,18918,12581,12645,10533,10533,10532,8452,10533,10532,12612,12612,12613,12645,12613,12645,12613,12645,14725,14725,12580,10499,10499,14659,18819,18755,29187,27075,24961,29155,8321,4160,14626,12513,16771,18982,10499,4128,4096,4096,4096,4096,4096,4096,4128,4128,4128,4128,4096,4096,8256,8288,4128,4096,4096,2048,2048,4128,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4259,6340,23178,10532,8419,20998,12612,14724,20998,18885,8419,10533,10533,6372,8452,10533,10533,14694,18984,21064,29482,12645,12645,31562,35723,31465,31498,27369,20999,18919,6339,6371,8452,8419,16805,10532,10532,8452,8452,10565,8452,21031,12613,10532,14725,12580,12580,12547,12579,16706,16674,16674,20867,18754,8353,4160,14626,10401,20964,21030,12611,4128,4096,4096,4128,4096,4128,6176,4128,6208,6176,6208,6176,4096,6208,4128,12448,16576,4096,0,2048,4096,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4259,6340,23178,10565,6371,25191,10532,12580,18885,12612,6339,10533,8452,8420,16838,14726,23050,14694,18920,23145,18887,16838,18919,16838,35756,29384,29449,31530,20999,18919,6339,8420,10500,8420,18918,12613,10564,10500,8452,10532,8452,18886,12613,10532,14660,12580,12612,8386,14627,20900,25158,12514,14594,6240,10433,4160,8385,18851,16738,23208,21128,6240,4096,2048,2048,4096,4096,6176,6176,6208,4096,4128,4096,4096,4096,4128,8288,18656,16608,4128,2048,6176,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4259,6307,16904,10565,8420,29416,16805,23078,25191,8387,4258,10533,8420,8420,23112,21000,18857,14695,16744,27213,12613,23080,23144,27304,23145,18919,16839,10533,10533,10501,8420,14726,12645,8420,18918,16838,18919,20999,10532,10565,14726,10500,12613,10499,12579,8354,8354,6306,23045,18852,23077,14627,14594,4160,8320,4128,6241,12546,12545,23176,18983,10433,8288,4128,4096,2048,4096,4096,4096,4128,4096,4096,4096,4096,4096,2048,6208,8288,8256,24864,12448,4128,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6308,6308,21097,10533,8420,16805,10532,10500,16773,6307,4258,10565,8420,10468,23144,18919,14663,14662,14695,29389,16807,12614,10533,14758,10500,12613,14726,10500,10533,10500,8388,12581,12613,10532,18886,10532,16805,25224,10532,10532,12613,10500,12613,12580,23078,8386,6338,6306,20965,12547,10466,12547,10466,4160,10434,8353,12578,8321,10465,14757,25322,12546,4128,4128,4128,2048,2048,4096,2048,2048,2048,4096,4096,4096,4128,4128,4128,4096,4096,10336,10368,20736,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4260,4259,16840,8484,6371,10532,8452,10533,27271,8387,6339,12613,14693,10468,25257,23144,10469,25193,18919,39917,21032,14726,12613,33642,21031,16806,10500,8420,12613,12613,14758,14693,14693,25223,27271,12580,12613,29450,14693,14726,8419,10500,12613,10533,14725,12612,12580,8419,14660,18853,18917,10466,6273,4160,4160,4160,18884,14626,12546,10498,12611,6240,4160,4128,2048,2048,4096,2048,2048,2048,4096,4096,6176,6176,4128,4096,6208,4096,4096,2048,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6308,6340,14791,8484,6371,8452,16805,23078,29286,8387,10500,23079,35626,10469,18951,16871,6340,25224,14726,14758,40078,25191,27239,18918,25224,18886,10500,8420,14660,14660,14725,12612,16805,31496,25191,12612,16806,29482,12613,10532,8419,8419,12581,10532,10500,16806,23111,20998,25159,16772,25223,8386,4193,4128,0,2048,8385,6240,6240,4160,6240,2048,2048,4128,2048,2048,2048,4096,4096,2048,4128,2048,4096,6176,2048,4096,4128,10434,4096,2048,4128,4128,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6308,6340,23178,10533,8420,16805,12612,12580,18885,6307,6307,14694,18887,8420,14758,16838,14725,16838,12645,10533,16838,14693,16806,27337,16806,16806,21065,12613,10532,10532,10500,10500,10565,16805,18918,16806,21031,14725,10532,10532,12612,8387,10532,10500,8452,10500,12580,16805,12547,10499,16836,6273,2080,2080,2048,2048,4128,4128,4128,4128,4128,4128,2048,2048,0,0,2048,4096,4096,4096,2048,4096,4128,6176,2048,4128,8386,4096,4096,4096,2048,4096,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4259,6340,16872,10533,8420,31529,14725,18886,23078,6339,8419,18918,23079,8420,14759,14758,29450,10533,10533,8452,6371,10533,12645,37836,35789,25224,10533,8420,10500,10532,10532,12645,10532,10564,21031,14693,18918,21031,10532,10467,8419,10500,6339,8387,8419,8419,12516,8418,18884,14692,12579,4160,4128,4128,4128,4128,2048,2080,2048,2048,4096,4128,4096,4096,2048,0,2048,4096,4096,4128,4096,4096,4096,4096,2048,4096,6240,4128,2048,4096,4128,4128,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4259,6340,12646,10533,8420,16838,14693,18950,25191,8419,8451,18887,10533,8421,12646,14758,8452,23177,23145,6371,12645,10532,8452,14725,14725,12645,8420,6339,8452,8419,14758,12645,12645,8419,16838,12613,12645,23144,10532,8419,6306,8387,8387,4258,10466,14691,12579,10466,16772,8353,14594,12449,6240,6208,4160,4128,2080,0,2048,2048,4161,8421,8388,6274,4128,2080,2048,4128,2048,4096,4096,2048,2048,2048,4128,4096,6273,2048,2048,2048,4128,4128,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4259,6372,12646,10565,8420,29385,12645,14693,25159,10500,10500,23112,25192,8421,14727,16839,8420,16839,18919,8420,25191,10533,8452,29450,12613,12581,16838,10565,10533,10500,16838,21096,16838,8419,21064,12645,12645,23111,12612,10532,6339,4226,4193,10499,20998,35657,25125,16740,20965,27336,8385,4160,10401,2048,4128,6240,10465,4160,0,2048,4194,10667,23180,20835,4129,4194,4194,4128,4096,4096,4096,2048,0,4096,4128,2048,4128,2048,2048,2048,4096,4096,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6308,8421,18953,10533,8420,14726,20999,25191,25191,10500,10500,20999,18919,8421,10501,8421,8388,10533,12646,8452,12613,10533,10500,14758,12645,12645,12645,12645,10533,10500,10532,14758,18919,12613,21031,12645,10500,25224,10532,8419,6306,6338,6339,14692,16804,31464,14659,20966,23111,16772,23078,12578,2080,2048,4096,4128,2048,2048,2048,2048,12648,16807,6306,8289,8389,6275,4160,6208,4128,4096,4096,2048,2048,4096,4096,2048,4096,4096,0,2048,4096,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4260,8421,18985,10565,8420,10500,18918,16806,14693,8420,8387,14726,12613,10469,14695,14726,8388,21033,18919,12613,8388,10533,21031,29417,16838,14725,8452,6371,10533,14693,10565,14725,18918,25191,29417,18918,10532,25256,10532,8419,10532,8419,6339,14725,23079,29287,25093,29320,29352,12546,12579,10466,2080,2048,2048,2048,2048,0,4128,2048,6274,21034,8453,4161,12680,10565,2080,12612,10499,4096,4096,2048,2048,6176,6176,4096,2048,2048,0,2048,2048,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29094,27144,10533,8420,8420,25256,23111,31497,14725,12580,23079,10501,10469,12614,16871,8388,21000,21000,10500,10533,12613,25191,10533,10500,12581,8420,8420,14726,27370,12645,12613,16806,35755,23079,12645,10532,25224,16806,12612,10532,10500,8452,16871,25225,37739,16740,22981,20932,14627,12513,8320,4128,2048,2080,4128,2080,0,2048,2048,0,10468,8354,6241,10501,4160,2113,6274,8353,4128,4128,2048,2048,4128,4128,4128,4096,2048,0,2048,2048,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12484,14662,10533,8420,6372,21031,23111,20998,10533,12580,23047,18919,8421,12614,16871,14694,14694,16839,10500,12613,14758,27337,8420,10501,10501,12678,8452,10533,14725,10565,16838,21032,23111,18918,14725,16838,16805,14693,12645,10500,20998,10531,8451,20999,37804,18820,16740,14627,16707,12449,12448,4128,4096,4128,0,0,0,2048,4128,2345,2146,2114,4194,4128,4194,2048,4128,4128,6241,2048,2048,4128,10368,4128,2048,4096,4128,2048,2048,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10533,8420,8420,10533,10533,8420,8388,6307,8421,14694,10469,10502,12614,23112,10533,10501,25290,25224,21031,23144,8420,14694,16838,8452,10533,10533,10533,10533,14758,21064,35756,18983,14757,12645,14758,16805,12613,12644,27335,14692,10532,16806,27207,16740,14659,8354,6273,10368,10368,4128,4096,4128,2080,0,0,2048,4128,4261,2147,6605,6439,2048,6307,2080,4128,6273,4096,4096,2080,2048,2048,4096,2048,2048,2048,2048,2048,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10533,8420,6340,10501,10533,8452,8388,8388,8389,10469,10501,10501,8420,35788,16806,14694,8388,25224,23112,27370,10500,12613,12646,8420,23112,18919,23112,21064,27437,37869,33675,27369,23209,18983,25289,21096,21064,18951,21063,16870,14725,21031,23046,10499,12579,4193,4160,4128,6208,4096,4096,4128,4160,0,0,2048,2048,4228,4129,6505,12778,12678,2048,2048,4193,4128,4096,4128,0,2048,2048,4096,2048,4128,2048,2048,2048,2048,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10533,8420,8388,10501,10533,8452,8420,8420,8421,8388,10501,10501,8388,16806,12581,10501,8388,16806,16839,18919,8420,10533,10501,8420,14694,16806,25224,25257,29515,37869,35788,33708,31595,25289,33708,31595,29515,25289,21096,18950,14725,25191,29384,12579,12546,10433,8353,4128,2048,2048,2048,2048,4096,2048,0,2048,2048,8454,10600,2080,4161,8484,4128,2048,0,2048,2048,2048,2048,0,4096,2048,2048,2048,2048,2048,2048,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10533,10501,10501,10501,10501,10533,10501,10501,10469,10502,10501,8421,10501,10501,10469,8421,10501,10501,10501,8452,10501,10533,10533,12646,14758,18951,23209,29517,27370,29482,27434,25322,25289,25289,23176,27337,35657,18950,14725,14725,20998,27206,16739,8386,10433,6241,4128,4128,2048,2048,4128,2048,2048,2048,2048,2048,4227,10500,16970,4160,10500,8388,4128,0,0,0,0,2048,2048,2048,4128,2048,0,4128,2048,2048,2048,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10436,24900,8388,6340,6340,8388,8388,6340,6340,6340,6340,6340,6372,6340,8420,8388,10533,12614,12613,12614,25192,21065,18984,23112,23209,35825,27370,29483,29515,27402,31529,27369,25224,29416,46123,18950,12644,12644,14725,18820,10466,8386,10466,12546,4128,4128,2048,2048,4160,4128,2048,2048,0,2048,4227,6438,8386,4193,6241,4128,2048,2048,2048,0,0,2048,0,2048,4128,4096,2048,2048,4128,2048,0,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12516,41640,16806,4259,6340,6340,6340,8388,8388,8388,6340,12645,6339,6340,8388,8420,10533,12614,14694,16839,37804,38000,31661,29450,27370,29483,46124,42192,31595,31530,48400,44075,25191,29416,44043,14692,23045,14691,10498,16772,10466,10466,14659,10466,8321,6240,4160,4096,4128,2048,4096,4128,2048,4128,12580,4227,2080,2048,4096,2048,2048,2048,2048,0,0,0,0,0,2048,2048,2048,2048,2048,2048,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10598,19017,23210,14759,8486,10566,10533,8421,8421,8485,10534,6373,8421,8421,14759,10533,10469,18887,14694,6340,8421,8453,8420,8421,10501,10501,12613,10500,10500,8452,10501,10501,12646,14727,14759,18953,38067,57117,46518,44373,31628,31598,35723,37934,29482,27370,37868,27304,21031,23111,33609,12612,16772,14692,20998,31465,12579,18852,23110,16837,10466,6305,6240,4160,6208,4096,2048,2048,2048,2080,6274,4393,4194,2048,2048,2048,2048,2048,0,0,0,0,0,0,2048,4128,2048,0,2048,4128,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8388,12646,40080,48466,18951,8453,19016,10565,4227,4227,8485,25355,4227,4259,4227,10565,6372,4226,4227,4259,4226,4227,4227,4227,6307,6307,6307,23176,18853,12579,10533,6340,6307,4259,6308,6340,10534,27503,40245,23309,21163,39950,33644,18984,37902,33643,16838,14758,10533,8452,6306,6306,8419,8419,2113,16773,37835,23111,31562,29416,33708,18884,10466,6273,6272,6240,4160,4128,4128,2080,2048,10566,6240,4128,2048,4128,2080,2048,2048,2048,2048,0,0,2048,2048,2048,2048,2048,0,2048,2048,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14597,12614,27435,27370,14823,25322,31628,14726,6339,6307,8485,27435,4227,4259,4227,18984,4259,4226,4226,6307,4259,4227,6307,6339,6307,6340,8452,37966,23045,23045,16871,6340,4259,4259,4259,6340,8453,21097,33741,21097,14759,42095,37804,21065,46419,35788,14757,18950,6339,4258,2145,4193,4193,4193,2113,12580,29482,27402,23144,29416,35854,25223,16738,12546,8321,4160,4160,4096,2080,2048,0,6307,4160,4096,4096,2048,0,2048,2048,2048,2048,2048,2048,2048,2048,2048,2048,2048,0,0,0,2048,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4435,4402,14661,8453,8453,10533,10565,35854,37933,16870,18983,25192,12613,14823,4259,6307,4227,19016,6339,4226,4227,16903,25289,4259,8420,12645,8452,8420,10468,25256,8420,8387,16903,8420,6340,6307,6340,6340,8420,21032,48467,33708,12646,12646,12646,12678,16838,14758,12613,25289,16805,4258,4193,4258,4225,2113,2113,8387,16805,14693,14660,16804,31595,48500,41997,25157,6273,4160,2048,2048,2048,2048,0,10600,12614,4193,2048,2048,2048,2048,2048,0,2048,2048,2048,2048,2048,2048,2048,2048,2048,0,0,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4234,8729,2325,10566,6372,6340,6340,8485,14791,33642,16871,37967,37901,12678,31661,14758,8452,4227,19048,8420,10565,12645,12646,12645,4259,4227,4227,10532,18919,23145,31594,8388,6308,10533,8420,8388,10533,8420,21065,16839,25225,35788,16871,10501,10469,10501,27371,23176,6371,10564,12612,14725,4225,12710,10564,4258,4193,4193,12579,37804,18886,16741,25158,29416,44240,37803,23012,8353,6240,4128,4128,4096,4128,2048,4161,6241,6241,6241,4193,2048,2048,2048,2048,0,0,2048,0,2048,2048,2048,2048,4128,2048,0,0,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2220,12955,147,8486,4324,4260,6372,12646,6372,29450,12645,21129,21064,12678,27467,23177,8453,4259,21129,6340,12645,4227,10533,16839,4259,6372,8452,8386,27044,16741,20965,6340,8420,10565,12614,21032,16838,8420,18984,16806,25225,31531,8421,23178,31597,8388,21064,14757,6339,10499,10499,16837,4226,21194,14789,4193,6306,12645,12580,39917,29451,8386,12579,20965,44208,35723,25158,6273,4160,4128,4128,2048,2048,2048,2048,2048,4096,4160,2048,4128,2048,2048,2048,2048,2048,2080,0,0,0,2048,2048,2048,2048,2048,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,175,13053,2226,6437,6373,4260,4260,8453,6340,16871,8420,8420,10533,14791,37999,33772,10565,6308,16903,6308,6307,4227,6308,6308,4259,12678,12677,6274,35300,16709,23078,10533,16871,33674,21031,44241,33643,10501,8388,6308,18952,21032,6340,16872,27403,8388,14790,16870,8419,4193,4226,12645,4226,4258,4258,2113,27304,18917,10499,33578,27272,14628,20966,25223,16772,16804,16771,6240,4128,4128,4096,4096,2048,0,0,2048,2048,4128,2048,4096,4128,2048,2048,4096,2048,4128,4128,2048,2048,2048,2048,2048,2048,2048,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,177,13117,6483,4325,4260,4227,4227,8453,8420,4259,8453,10566,14725,10565,25355,12646,8388,23145,16806,6308,8421,6340,8453,10533,4227,6308,6306,6274,29091,18854,33576,18919,44339,44207,21031,18952,14726,8420,6340,6308,18920,14727,6373,14726,27371,6340,12645,10564,14725,2145,4193,6306,2145,4193,6338,2080,8386,6273,2080,12580,20903,16711,27211,14693,6305,6273,6273,4160,4128,4096,2048,2080,4128,2080,0,2048,2048,8452,6273,2080,2048,2048,2048,2048,2048,4128,2048,2048,2048,4128,2048,2048,0,2048,2048,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,177,13117,6483,6373,4292,4259,4227,6340,6340,4227,12646,14790,8420,6372,19017,6307,6308,10501,14726,10533,27404,23113,12646,10565,10501,8420,8419,8386,14660,31563,29417,18952,37967,42028,20999,16774,8388,14726,16774,6307,6308,6340,6308,12646,23210,6340,4226,4259,21128,4226,6306,21030,4193,32,2112,32,4226,6339,10405,12454,14596,14566,14533,12484,6273,4193,4128,4128,2048,2048,2048,2048,2048,2048,2048,2080,2048,2048,0,0,2048,2048,0,2048,2048,2048,2048,2048,2048,4128,4128,4128,2048,2048,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,179,13117,12724,4292,4260,4260,4228,6308,4260,4227,12646,16904,4227,8453,14791,6308,6308,4227,12678,12614,40113,31564,31432,31400,23112,18887,29385,16804,16805,48467,42060,14758,16871,46221,20967,12581,6340,31498,23079,18854,8388,6308,6275,23178,25290,12678,4226,4226,4226,4258,8420,27401,4225,2145,4226,32,6307,6307,10437,14566,4161,8322,12515,8322,4193,4192,4160,2048,2048,2048,2048,2048,2048,2048,2080,4193,0,2080,0,2080,0,2048,2048,2048,2048,2048,2048,0,2048,2048,2048,4096,2048,2048,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,179,13118,16789,4260,4260,4227,4227,4228,4228,4228,20968,14791,4227,12646,23243,10534,6308,4260,6308,8421,14759,27272,33512,54676,44044,21000,48500,37803,29385,31563,27369,12613,16806,46221,23079,14661,6308,29385,18886,12581,6308,6308,4228,16872,25258,6307,8419,8420,12612,8387,4226,27433,4258,2113,4226,2113,10500,6307,6243,29165,18791,4129,6274,12451,6274,6241,4160,2080,2048,2048,2048,2048,2048,2048,2048,2048,2048,0,2048,2048,2048,0,0,0,2048,2048,2048,2048,2048,2048,4128,4128,4128,2048,4128,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,180,13150,6356,4260,4260,4228,4227,4228,4228,4227,6341,6340,4227,6340,14759,25323,6340,4228,6308,8389,10502,10534,29353,46223,35723,18951,37934,27304,27304,25257,35657,14693,20999,41996,16774,10469,4228,20999,14694,6308,6308,6308,6276,12614,18920,10501,18952,10499,6306,2113,6338,29481,4226,4194,4226,6241,2113,2080,2081,8387,12485,8323,8324,4129,4161,8355,4160,2048,2048,2048,2048,2048,2048,2048,2048,2048,2080,0,2048,2048,2048,2048,0,0,0,2048,4096,4096,2048,2048,2048,2048,2048,4128,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,181,15230,2195,4260,4228,4228,4228,4228,4228,4228,6309,4228,4228,6309,8422,40176,8421,6309,6341,12582,21066,18888,29385,50579,39980,18919,27403,14693,18887,21032,46121,10469,10469,33578,16839,10469,6276,25291,25225,37802,8388,6308,4228,12614,12678,18919,16839,8419,10467,4194,4193,10466,6274,6307,12580,4193,4193,0,0,2113,10405,8292,6210,10403,6241,2048,0,2048,0,0,0,0,0,0,0,2048,2048,2048,0,2048,0,0,0,0,0,0,2048,2048,2048,0,2048,2048,2048,2048,0,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,181,15197,6420,4229,4229,4228,4228,4229,4228,4228,4229,6277,6341,6309,8390,16840,8357,10502,16808,23146,50646,35822,23080,27337,44140,12614,21033,31562,14694,25258,39848,10437,12582,25160,10469,6309,6276,10470,10469,16806,6308,6276,6276,14727,16807,12581,8421,6340,8388,6308,8388,23111,4193,32,2113,6305,14659,4193,8356,6243,4161,10373,4161,2048,0,0,0,0,2048,2048,2048,0,0,0,0,0,0,0,0,0,0,0,0,2048,2048,0,0,0,2048,4128,4096,2048,0,0,0,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,181,15197,6420,6278,6278,4230,4229,6278,6278,4229,6278,6310,6278,8358,10438,14663,14695,33676,27338,18954,35791,23114,12584,14696,33610,8358,14696,16806,12583,14695,14663,12551,27339,37706,10438,8358,6277,6277,6277,14695,8357,6277,6309,21001,18920,25193,6276,6276,18919,4194,6307,23078,4193,2113,2113,8387,10499,4226,4193,8387,2112,2080,14692,6306,6241,10433,2080,8288,12449,6208,2048,2048,0,0,0,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,2048,2048,2048,2048,2048,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6358,19293,14806,8298,8298,8298,8265,12491,10378,10346,25133,23020,12425,14506,25003,39886,18793,44208,29356,14570,14602,12490,10409,16714,42064,10408,10409,10439,10376,10376,14569,14601,46356,41899,12488,12489,10408,8328,8327,8327,12521,14633,10408,37904,23082,12519,6278,8357,18919,4195,4162,10501,8323,4194,4195,6275,8355,16739,6275,6306,6274,6307,4160,2048,10433,10466,2048,2048,4128,2048,2048,2048,2048,2048,0,0,0,2048,0,0,0,0,0,0,0,2048,4128,0,0,0,2048,2048,2048,2048,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,31159,35353,35353,33370,33369,31321,31289,31289,31321,31321,33370,33369,31321,31289,31289,31321,31321,33369,29050,27035,29502,27066,33177,33145,31097,31097,33177,31065,31065,37560,35384,33112,37272,54585,43766,31063,35256,31063,31032,28952,28951,28919,28918,31062,26806,26806,22739,22644,24725,35509,24724,28979,45972,29074,37684,24786,24819,22706,20530,20529,18481,20562,31378,22799,16430,16430,16462,24942,12331,12362,14475,25098,14599,10343,10375,21002,14600,6213,4162,6242,6211,6211,4129,4129,2048,4096,4160,4160,4128,2048,2048,2048,2048,2048,0,0,0,0,2048,0,0,0,0,0,0,0,2048,2048,0,0,2048,0,0,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,26962,24691,26901,24789,24789,24821,22677,24790,24726,24726,26774,24662,24726,22677,41814,29014,22679,26871,26839,24695,28791,26711,28824,26807,24727,26808,26776,28888,28920,28888,33016,30936,37336,39511,44025,33144,33113,31065,33114,31033,33081,33113,33145,35257,33209,37465,33208,33208,37338,35290,45913,41690,37434,39482,37402,39546,37434,37370,39387,37339,37403,39419,39547,37370,35291,41659,39419,37371,35098,37211,35130,37337,31031,28920,31065,37559,33144,24758,22708,20561,26838,26774,14411,16462,6149,6180,4128,2048,2080,4128,2048,2080,2048,2080,0,0,0,0,2048,2048,0,0,2048,0,0,0,0,2048,2048,2048,2048,2048,0,2048,0,0},
{0,0,0,0,0,0,0,0,0,0,20996,23076,27205,23078,8389,16775,12550,14728,18856,23049,12552,10504,8359,12553,6279,10504,10472,25193,16713,6279,12521,12521,6248,12489,8296,12489,12490,6248,12522,8328,12490,14570,20908,14570,10377,23053,18795,27342,16651,12490,12458,14539,8297,14538,12490,16747,16619,8297,25068,22955,16711,16620,12394,37709,25068,12394,18668,12458,31504,18731,18700,16588,14476,14476,18637,12395,16587,14506,39790,20779,10314,16586,16586,10344,12457,8262,8294,12455,29320,10374,6180,14567,8292,6148,4131,4129,4130,2048,2080,2048,2048,2048,0,2048,2048,2048,2048,2048,2048,2048,2048,0,0,0,0,0,0,0,0,0,2080,0,0,0,2048,0,2048,2048,0},
{0,0,0,0,0,0,18884,23012,20963,23043,33639,33607,35687,31396,23012,27237,27205,29383,33577,33576,12614,12614,10502,10534,4229,8422,10470,6309,10503,6310,8422,10470,12582,10471,10502,8390,10439,4229,14664,14664,8358,12583,33710,10471,8358,8358,12552,6278,12519,10439,6278,10471,6277,12519,10471,31597,12519,6277,20969,20936,25192,8389,8326,12551,8390,6277,12551,8390,10438,12551,6277,12519,10438,8358,12551,6277,12551,12550,48171,18855,6276,10470,8356,6276,10437,6308,6242,4194,6307,4194,2081,8387,4161,2080,6306,4193,2048,2048,2048,2048,2048,0,0,2048,2048,2048,2048,2048,2048,0,2080,0,0,0,0,0,0,0,0,2048,2080,2080,0,0,0,0,0,2048,0},
{0,0,0,0,12611,14691,35654,37734,35686,35718,37767,37799,39880,41960,39880,37833,39880,39913,41994,31463,16773,16806,18918,16774,10469,8421,14694,39818,27274,23082,8389,10502,12582,25160,18855,6309,10470,4228,18921,14663,4228,12582,12550,10470,10470,12582,10470,4228,10470,8422,4228,10470,6277,25127,16775,12582,10470,6309,31498,20968,25192,8389,8326,12551,10438,6277,12551,10438,8357,10470,6277,10470,10438,6309,10470,6277,12550,12550,35592,16743,6276,10469,10469,4227,6275,2114,2113,2080,2081,4194,2048,8386,2113,2113,4225,4193,2048,2048,2048,2048,2048,2048,2048,2048,2048,2048,2080,2048,2048,2048,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,20932,39815,39847,39815,37767,35720,35687,37734,37767,39847,39847,41927,39847,41960,41992,44073,44041,44073,41960,41960,44106,41960,31463,8389,14663,23047,20936,18856,12519,10470,4229,12582,10470,4228,10470,4229,18921,12583,4229,10470,6277,10470,10470,23080,10470,6277,8390,10470,4228,10438,6309,18822,16743,12647,12550,10470,25161,18855,25160,12550,8358,12550,10470,6277,12550,10470,6309,10470,6277,10470,10470,6277,10470,6277,10470,14662,41961,16743,8324,6308,8355,10500,6275,4162,4161,2113,0,0,2080,14691,4193,6273,12611,4160,4160,2048,2048,2048,0,0,2048,2048,0,0,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2048,0,0,0,0,0},
{0,10531,27236,41992,23010,25123,23043,18915,20963,27203,27202,29283,31364,31363,31331,33509,31397,31430,29318,29319,23046,25159,23046,25127,20872,6278,10439,6278,20874,14600,12488,10440,6246,10440,10440,4198,10472,6278,10440,12520,4198,12520,8327,10440,10440,6246,12520,8326,8358,10471,4198,10439,8358,8358,10439,6310,10439,8390,23049,16712,16711,12519,8358,10471,10470,6276,10471,10470,6277,12551,8325,10471,10470,6277,12519,6277,10471,12551,8357,12551,10405,8356,6308,4194,6275,2114,2048,2081,0,4194,2080,4193,2080,2048,6273,2048,2080,2048,2048,2048,2048,2048,0,0,0,0,0,0,0,0,2048,0,0,0,0,2048,0,0,0,0,0,0,2048,2048,0,0,0,0,0},
{0,12611,35524,41960,14658,35720,39913,31592,31592,35752,39912,41993,44044,43981,43981,41933,43982,37614,31279,22768,14413,22673,18543,18544,24882,31217,18579,16465,35539,22707,16433,20627,16465,26994,20659,12335,18579,16465,29137,22738,12304,22771,20690,16464,20626,14382,20658,18576,18574,18576,12334,18576,16528,14414,18608,12333,18608,16528,31280,22768,18670,18639,18639,25132,14474,10345,16589,16589,10315,18638,12395,16557,16589,10346,16589,12426,14507,16620,18698,16619,10377,10343,8295,4132,6180,6213,6212,8261,2081,4162,4162,4194,2048,2080,2080,2048,4128,2048,2048,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2048,2048,2048,0,0,0,0,0,0,0,0},
{0,12611,29348,39914,18851,42125,31428,12610,12610,12611,16739,25098,45915,41531,41435,39451,39452,39484,41692,39484,37404,39452,39452,39452,41532,39516,37405,39453,45916,41596,41596,39485,39453,39485,39420,39421,39421,39421,41724,39452,39484,39484,39453,41501,41500,45756,41629,41500,39420,39388,39420,39420,39388,39420,37372,37404,39452,39484,43772,41596,39484,39484,39452,43739,31032,33146,28952,33178,35291,39451,39547,37371,37371,35258,37370,35290,35289,35289,45944,35257,33144,28983,26870,24788,24789,22675,22674,20561,16494,14411,12363,6182,10249,6150,4129,2048,2048,2048,2048,2048,2048,0,2048,0,0,0,0,0,0,0,0,2048,2048,0,0,2048,2048,2048,2048,0,0,0,0,0,0,0,0,0,0},
{0,14659,31428,39847,16771,44272,29315,12610,10498,14659,10498,33485,43673,27086,20780,20716,18605,16525,31375,16526,12333,16559,16526,16526,18607,12333,16527,16559,31344,24944,22864,18576,18576,14383,18576,12334,18576,18576,14383,18577,14384,18577,18577,14383,29073,29039,35507,24880,14382,18576,14384,18577,18545,16432,20625,16433,18546,20626,31123,22642,18482,20595,22643,31123,20655,14382,16495,18451,18451,22644,22580,22612,24692,20499,26740,24661,24661,26773,24693,28886,26806,30997,26804,22643,22643,26836,24788,20625,24787,18543,16526,18543,20657,12363,4130,4129,6178,2048,2048,2048,0,0,0,2048,2048,0,0,2048,2048,0,0,0,0,2048,2048,2048,2080,2080,0,0,0,0,0,0,0,0,0,0,0},
{0,14659,35589,37734,16738,40013,27235,18851,25123,41960,41960,44074,29353,21032,16838,14726,29320,12550,18920,10470,4229,10470,8422,25161,10471,6277,12519,12519,23050,16744,12519,16712,12519,8390,10471,6277,10439,10471,18890,10439,6278,10472,10471,8326,18824,14566,37870,20970,12551,10471,6278,10439,10471,6245,16745,10439,10439,12552,31435,18792,12519,10439,12520,12487,16712,12518,4164,12552,8357,14601,12520,10440,14601,6279,14601,12488,10408,14601,8327,14601,12488,29323,12487,6245,10406,12487,6244,8324,6244,6275,8355,6274,0,2080,2048,2048,4128,2048,2048,2048,2048,2048,0,0,0,2048,2048,2048,2048,2048,2080,2048,2048,2048,2048,2048,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,14659,37701,37668,18916,46286,31363,29350,35687,39815,25123,31429,18917,23078,8420,8452,23078,12613,10533,8421,4228,8389,8389,12613,10469,4228,14727,10469,27339,14663,18921,27274,12582,8357,10469,6276,8389,8422,18953,10502,6277,10470,10470,8357,16775,23015,37934,21001,14727,10470,6277,8390,10470,8357,10470,6309,10438,14662,33545,20967,16743,8390,10502,20968,27339,25227,6275,14694,18951,12581,10438,8390,12551,6277,12551,10470,8357,14631,20904,12551,12518,42029,16742,4195,12549,6307,6276,10469,6307,6274,4193,6306,2080,4160,2080,2080,6273,2048,2048,0,2048,2048,2048,2048,0,0,2048,0,0,0,2048,0,0,2048,2048,0,0,0,0,0,2048,0,0,0,0,0,0,0,0},
{0,14659,39847,33508,16770,46219,29218,16771,37800,37669,14659,27270,18853,14692,14725,12612,8420,8452,18919,8420,4227,6340,8388,6308,10501,6307,8420,10501,23145,16807,25225,33479,14661,12549,10469,4227,8388,8421,12582,8421,4228,10502,10469,8388,12614,12613,33741,21033,4228,10469,6276,8389,10469,20966,12550,12647,10469,16774,41929,18919,14726,6341,12582,27304,18888,14727,6340,8452,18951,18918,8388,8357,12551,14630,12550,10469,8357,20968,33513,14662,12582,31465,16775,6308,10501,6339,4195,10468,6274,10468,6274,6273,4193,6305,4160,2048,4128,2080,0,0,2048,0,0,2048,2048,2048,2048,0,0,0,0,0,2048,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,14691,39880,31394,16738,46186,25090,12578,39879,33508,10498,18884,12612,21095,10532,8451,33576,14693,18950,8420,4259,10468,8420,8422,27304,25159,6340,8420,12581,18919,18887,8420,14693,39880,10501,6308,6340,8453,6308,8421,4228,16807,12549,8356,10469,8388,35854,16839,4227,8421,6308,6308,8421,4227,10501,8421,29287,20934,27239,12581,10501,6340,16807,31498,12581,10469,6308,8420,31594,18918,10499,8390,12551,6276,10501,10469,8356,20935,27239,12582,12549,46123,16742,4227,8388,6307,4227,8387,4226,6306,2080,4160,4161,6241,6273,4128,4192,4096,2048,2048,0,0,0,2048,2048,0,0,0,2048,2048,2048,2048,0,0,2048,2048,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,14691,39881,29282,18884,44172,25123,14658,39913,33476,10498,31495,12612,21063,10532,8451,25126,18918,27304,8420,6307,29385,10500,12645,25224,18886,6307,8420,14662,16806,14694,20999,18853,41994,12581,8388,6340,12646,18952,8421,6308,10502,14662,39850,12549,8388,40079,18919,10468,8421,6308,6340,10469,4227,8421,8389,44106,31431,33544,10501,8388,6308,14694,35690,10501,10469,6308,12614,16902,16742,8356,8357,14631,6276,12551,10469,6308,12582,8389,12582,10468,44041,14660,2145,4194,6307,2113,8387,6306,4193,4193,12579,2080,4160,4160,6240,23043,6240,2048,0,0,0,0,2048,2048,2048,2048,2048,2048,0,2048,2048,0,0,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,16739,44073,29249,18916,44139,23010,12610,39913,31395,10498,27302,12612,25256,10500,8451,29351,16805,14725,8420,6308,12645,12613,18886,25192,14693,6308,12614,14662,16807,10469,33577,16773,31496,23112,23144,6308,12646,16807,8421,6308,12615,12614,39849,12549,8388,18952,18855,20935,10469,8389,8357,10501,6276,10469,10469,39816,25094,37737,27272,16774,6308,14694,29384,16775,12582,6308,14759,16904,23048,10469,6308,12550,4228,12550,10501,8356,12550,6276,12550,10501,39849,14661,4194,8355,8420,4194,8388,4193,14660,8386,10466,2080,2080,2080,4160,8320,4096,2048,2048,2048,2048,2048,2048,2048,2048,2048,0,0,0,2048,2048,0,2048,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,16739,46022,29185,16770,46186,29348,14690,42025,29315,10498,18885,12612,21030,8420,8420,35624,18918,21064,8420,6340,8388,10533,23111,20999,14726,4227,10534,10501,12582,10501,31496,18854,27303,23176,23112,6308,12614,12646,8421,6340,18920,12582,27240,16775,14694,33741,16807,12613,10470,8389,16742,12582,6276,10470,12550,44108,29319,39817,12582,10469,10502,12614,29385,25258,16775,12614,16775,23177,14663,10467,6308,10469,4227,10501,10502,6308,12582,6276,12582,12549,29351,8387,2114,8388,10469,8356,6274,2113,14659,10434,8386,2080,2048,2080,2048,2048,2048,2048,2048,2048,2112,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,18819,48233,27105,18818,46185,23043,14658,42025,27203,14691,16772,10532,12613,8420,8388,8420,14694,20999,8389,8389,4228,8421,4228,8421,8389,6276,10470,12550,18888,10502,12581,12582,14662,10470,8389,6277,12550,8389,10470,8389,27307,10470,6276,10470,10470,40144,16807,6276,10470,8422,6277,10470,6244,10502,14630,48267,25126,18887,12550,10470,8357,14663,27273,10502,10502,8357,16839,21064,23048,10468,6308,12550,4228,12550,10502,6309,12582,6276,12582,10469,23047,8388,4227,10470,12582,8356,4194,2113,8386,6273,6305,4161,2080,6273,6272,2048,2048,2048,2048,2048,2048,0,0,2048,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,20867,50215,25025,18850,46186,20898,18818,48265,25123,10499,23078,10500,12710,8421,10469,8389,23113,27306,14534,10438,4196,16776,12615,18888,8390,6310,12583,14631,23018,14631,18823,12551,12582,12519,10438,16776,12583,10471,12552,10471,12552,12519,8325,18856,14631,23146,18759,14566,12519,10471,6278,12519,6245,16776,20936,48365,31432,35657,23081,12550,31305,16743,31498,10470,10470,27273,23146,25193,14663,12551,6308,12551,6277,12550,12550,6309,12551,6277,12550,12549,18854,12550,6309,12583,10470,6275,10469,6274,6274,4193,6273,4160,2048,10465,14626,10433,4160,0,2048,10530,2048,2048,0,0,0,0,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,16739,35622,25122,18850,46185,18818,18850,50346,25090,12579,29417,12582,10470,18890,12520,14568,18858,12552,10408,10441,6247,23051,18857,23019,14569,8328,14569,16746,16682,16681,14600,12488,8295,14602,14569,12489,14569,10376,14570,12457,10376,14537,18794,41932,29290,33679,20938,16680,12521,12489,8296,14569,8295,27244,23017,46219,29321,33513,23081,14600,12455,18793,27242,12520,12519,31467,25194,29483,12552,14600,8326,12550,8326,12552,12552,6277,14600,8325,12518,14599,39851,14631,8326,12551,10438,6243,10469,8356,10436,10468,8419,8353,4193,12546,16738,14626,2080,32,2048,2080,0,2048,0,2048,2048,2048,0,0,0,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,27171,39749,20898,41959,16738,20930,48298,23011,12580,29323,24942,24912,20657,18545,20593,33523,31313,22706,20594,18514,22674,20626,22707,20594,16402,22642,20561,18513,20593,28946,22642,24818,22643,22643,18482,20594,18481,22738,20594,18481,20561,20529,44018,31184,22736,20592,18512,18545,18545,14383,20592,14351,33362,22830,48433,29197,31277,31311,22798,14381,20718,33456,16526,16557,12364,20845,33648,20845,22893,20717,16555,8264,16619,16588,8232,12489,10344,20811,18762,42029,16650,10377,14538,10376,8262,12456,8326,14631,8387,12612,2080,2080,6274,4160,6240,4128,2080,2048,2048,2048,2048,2048,2048,2048,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,35654,29413,37832,20930,16738,46153,20899,10436,20656,41597,41597,41597,41597,41629,39580,41628,41597,41597,41565,41565,41629,43741,41597,41533,41565,41596,41564,41565,41597,41565,39549,41565,41597,41597,41597,41565,41565,43645,41565,41565,41597,45853,43709,43741,41596,43708,41629,41597,41564,41564,41597,41629,41661,50364,43772,45788,43708,43644,41596,43644,43804,41596,41596,39548,41595,41723,41595,41595,39515,39483,33177,31064,37370,35290,26902,31031,37305,35256,43864,35255,31063,30999,28886,26837,26838,26772,22602,16453,14410,8200,6182,8262,10311,16553,2049,4130,6179,2080,2048,0,0,0,0,2048,0,0,0,2048,0,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,25189,35686,29381,39944,23011,12549,14442,33175,35416,24793,24793,37496,24760,31288,22745,24793,24856,24761,24825,28985,26873,24793,24729,22744,24761,24761,24824,24761,24824,24761,24761,26937,26809,24825,26809,26841,24793,26809,26873,28858,26841,31193,28985,37561,26809,26809,24793,26809,26873,28986,29017,28985,31033,37497,28922,28890,28922,28858,33114,30938,28858,26874,28858,28922,33018,28858,28858,28890,30906,28890,30907,28891,28922,22678,31003,33019,39483,35131,35164,35228,35163,35228,31067,35228,34927,37133,26808,26807,20563,18513,22676,28948,10250,14380,22674,8231,2048,2048,2048,0,0,0,0,2048,2048,2048,2080,2080,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,14788,27301,35621,20964,27053,41755,39643,37436,37435,37531,24954,25275,35419,39483,37435,37404,35355,37436,37436,35388,37404,37403,37403,39451,37403,39484,37436,37404,37404,37436,37436,37435,37371,37403,35355,37403,35355,37404,35387,39707,37467,46074,35355,35323,35290,35291,35258,35323,35354,33209,39351,43864,35193,33082,31033,33082,33113,31001,31001,26872,28921,26807,35096,26807,35096,30872,35096,30872,26743,28792,20595,14350,20561,14350,18513,14350,18513,18513,18481,12302,16401,12301,12297,8197,8199,6151,4099,2049,2049,4129,4099,4099,4098,4098,2048,2048,2048,2048,2080,2048,2048,2048,2048,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,14692,23141,23207,27243,24660,20502,22551,22550,20533,14388,8245,20534,22549,22549,22549,20501,24630,22550,22550,22550,24597,24598,22549,22550,24598,20501,22550,22550,22551,24631,24662,24630,22582,24662,26711,22582,24631,22615,26775,26711,26711,26776,24695,26776,28856,26775,28856,28856,35256,32949,33078,33080,33080,31032,33112,33144,33177,33080,33080,31032,33112,33144,33177,33145,26806,28822,28854,26806,18604,16493,18574,18542,16494,16495,16493,18574,18542,16494,16495,20657,22737,20559,20657,18510,8232,14413,4162,4162,18666,12362,10311,8263,12393,4130,0,0,0,2048,0,0,2048,2048,0,0,0,0,0,2048,0,0,0,0,0,0,0,0,0,0,2048,0,0},
{0,0,0,0,0,0,0,0,0,0,8389,18825,18636,12302,12335,10254,12335,10287,12399,12335,10254,12303,14383,14383,12335,12335,14351,12335,14351,16431,12303,14384,14352,12303,14384,10255,14385,14384,12303,14384,12303,14384,14384,12304,14387,12307,22898,20721,16463,18545,14351,16464,16496,12303,16497,14383,16495,16495,16493,20623,18574,16495,18576,16558,16559,16559,18769,25107,20847,18671,18574,18509,22639,12331,18636,14506,12425,12457,8295,10376,8294,16679,10374,6213,12454,6245,8293,6244,8324,6211,6211,4130,2081,2080,2080,2080,2080,2080,4128,4160,4160,2080,0,0,0,0,0,2080,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2048,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,6277,16591,29049,27001,27001,27001,27033,26968,28984,28984,26969,26969,26968,27000,27032,27000,27032,29048,29049,29049,29017,29017,29049,27001,24985,27001,29081,29081,29049,29049,26969,26969,29050,29050,27035,27066,29113,29081,43929,37498,31098,31129,31130,29050,29050,29050,29082,31193,31097,29050,31098,31162,33370,33337,33402,39931,50651,39929,33369,37529,35353,35321,31192,31192,29144,29112,29080,29079,26966,26965,33270,29109,27029,35381,27028,26995,24915,22802,22802,18608,16527,10315,6150,2049,2050,10342,2049,4098,4097,2048,0,2048,2048,2048,2048,2048,0,0,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,4230,6279,6280,4232,4232,4232,6248,4200,4200,4200,4200,4200,6248,6248,4200,4200,6248,6249,6249,6248,6248,6281,6249,6249,6249,6249,6249,6281,6281,6281,6281,6281,14853,23270,23270,6251,6250,31307,25099,20907,10409,10409,6217,6249,8297,10442,8361,6249,8297,10377,10410,27024,16653,18863,35894,57117,50682,25168,44049,35505,22799,22829,22766,22768,18606,20686,20687,22736,18606,18638,20686,22768,29010,24786,24913,24849,31155,24817,20625,18606,16461,10283,12488,6182,10280,6181,14444,8231,2048,0,0,2048,0,2048,2048,0,0,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40000,54663,35873,4171,6218,31404,20903,16712,6246,6215,6216,4198,4197,8358,6247,4198,4198,12520,12491,25006,18764,18926,33781,55004,46488,25198,35660,27179,23017,25066,20873,27209,18760,18761,29225,16648,16681,10406,12487,16649,10439,14568,18761,18855,16678,10405,6275,10468,4161,2081,6338,4193,12579,2048,2048,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2048,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37920,56646,35840,4201,6246,22984,14630,35660,18792,8389,4196,4197,6277,6309,4196,4196,4229,14695,4229,8359,10505,18957,33846,52891,48601,25197,46254,33548,14599,27178,20841,18791,16679,16680,22951,18792,16648,8325,10438,12486,8325,12486,18856,27304,14628,10436,4161,4193,4193,4161,4161,2080,2048,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2048,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,35808,54598,33989,6249,10407,41932,29191,12455,4197,4196,4165,4197,16840,23112,14727,4196,4228,12582,6278,6311,10538,18990,35958,52891,44375,25197,48335,33515,25097,18792,16679,12518,14599,16680,12518,14599,16712,18791,14599,14631,12518,12518,18792,23079,25095,12549,6275,10468,4161,2080,0,2048,12481,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,35776,54598,38054,6280,12519,46190,33414,8325,4196,2147,4196,4195,16839,23111,8389,4195,4195,6308,4228,6309,10537,18990,38006,57116,46488,27309,44076,27242,12519,14632,16680,12518,22985,18792,12518,14599,14632,12518,14631,16712,12550,10469,14630,16774,20933,6274,4161,10467,6274,4193,0,0,2080,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31584,54566,35811,18955,10438,42029,33446,8356,4195,4195,4195,4195,6340,8420,10533,4195,4195,6309,4228,4229,10536,18957,35893,55004,46488,27277,44044,31402,18791,14632,18792,20904,29289,25097,27176,14599,14632,12518,18791,18824,20904,14598,14663,10468,27206,8354,4193,6306,4160,4193,0,2048,0,0,0,0,0,0,0,0,0,2048,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27360,52582,31649,6279,8357,16774,12549,4227,4195,4195,4194,4195,4259,14694,4227,4195,4195,4227,4228,10470,12583,16778,31570,35989,33714,27212,46221,35594,20904,14631,18824,20903,18791,18824,20903,14599,16680,10470,14599,16711,14630,10437,14662,18886,27238,8354,4193,8386,8451,12612,2048,2048,0,0,0,0,0,0,0,0,0,0,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21121,50469,37920,4198,6276,6276,12549,4195,4194,4227,4194,4194,4195,20999,4227,4227,4195,4195,4227,8421,16746,14633,29294,29393,27247,27212,48365,33546,29321,12550,20968,35625,12550,14631,12517,10437,14599,8356,14630,14598,8389,14662,25162,23112,31431,8386,10466,12548,14725,16871,2048,2048,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16898,44163,40034,2150,4195,4195,4195,4194,4194,4194,2146,4194,4194,21031,4194,4194,6307,4194,4227,4227,14569,12519,27182,29295,27213,25099,48300,37707,22983,14631,16711,14630,12550,16711,14630,12550,14631,10469,16711,14631,12550,20935,18888,21000,33511,14628,8387,27272,14628,8387,4161,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25313,25314,4230,6276,6275,4227,6275,14693,4227,6275,10436,6275,8388,6275,6275,10468,6275,10468,18854,6276,10437,20938,25132,23051,22985,27241,23017,18824,20873,20905,18824,18824,18824,18824,18824,18825,18792,18825,18825,18824,23017,20937,20937,25128,14660,14660,16805,12547,10467,4193,2080,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4228,6275,4227,4227,6275,4226,4194,8387,10468,10468,4227,4195,4195,10500,4226,6307,16806,4195,6276,16806,18887,18887,18886,27239,20998,12548,12580,12580,12580,14661,12613,12548,12613,12612,12580,14661,14661,12580,14693,14693,14661,14693,10499,8386,6274,6306,6306,4161,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4228,4227,6307,12548,8388,6275,12580,8387,6307,4195,4195,4195,4195,4227,4227,4227,10500,4194,6275,14693,16806,16806,16806,20934,20934,10500,12548,10500,12548,12612,12580,10500,12580,12580,12548,12580,12580,12580,14660,14660,12580,14693,12580,6306,4161,2080,4193,4160,2080,0,0,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4227,6275,14693,42062,16742,8356,25159,18821,12515,4195,4194,6307,4227,4227,6307,4227,6275,8388,10374,12581,16774,16774,16773,18885,20966,12580,10500,10467,10499,10500,10467,10499,10500,10467,10500,10500,10500,10500,12580,12580,10499,8386,8386,8386,8386,4225,4160,2080,4160,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4227,8387,27238,42061,18886,12549,31432,16741,16741,12580,6275,6275,6275,6307,6308,6275,6307,8388,6275,10500,14693,16741,16741,14660,14692,12548,10499,10467,10467,10467,10467,10467,10467,8387,8419,10467,10467,10467,12580,12580,12580,8387,8387,10467,6274,4193,6273,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4226,6307,18885,46255,16774,6308,25191,8387,6275,23013,4227,6307,8388,14758,4259,4226,16805,4194,14692,14660,14693,14693,16741,12580,10467,12548,10467,10467,12547,10467,8387,8387,8387,8387,8387,8419,8387,8419,12580,12580,10499,10500,8387,8386,6306,2112,0,0,0,2048,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4226,6274,14692,37868,14661,8388,12613,6275,8355,14628,6275,6275,6275,10501,4227,6275,8387,25224,8387,8387,12548,8387,8387,8355,6306,20933,10435,6306,8355,6307,8355,6306,10532,6307,12547,20965,8387,10499,12547,10467,8419,8387,8387,8386,18819,4128,2080,2048,0,0,2080,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6274,8387,20998,31564,12581,18853,8388,25126,18852,16740,4194,4227,8420,10468,4194,4194,4194,4226,16773,8387,8387,8387,8355,8387,10435,18885,8387,8355,8387,14661,8355,10467,12645,8387,12547,23045,23111,23045,14660,14628,8387,4226,6306,10498,33477,14626,2080,2080,4160,2080,2048,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16547,12451,10435,18918,31595,6275,6275,12613,10500,6307,14660,2146,8453,8420,6339,2146,4194,4194,4194,4194,6306,8419,4226,6274,4194,4194,4194,4194,4194,4226,8453,6274,10532,4226,4226,6307,10500,14692,6306,14628,33510,10467,4226,6306,12547,27237,12513,4160,2080,2048,0,2080,0,2048,0,0,0,0,0,2080,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39363,20674,8355,10435,12580,8355,6275,8355,6275,6275,6275,6275,6275,6275,6275,6275,6275,6275,6275,6307,8355,8355,6307,6307,6307,6307,6275,6275,6275,6275,6307,6275,6275,6275,6307,6307,6307,6307,8355,10467,18820,10468,6274,8386,10466,31398,14626,4193,4193,2080,2080,2048,0,2048,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20643,24803,6275,8355,25126,10467,6275,8387,6307,6275,6275,6275,6307,8355,6307,8355,8355,8355,8355,8387,10435,12580,8387,8355,8387,8387,8355,8355,8355,10435,10436,10436,8355,8355,8387,8387,8388,8388,8388,10436,12548,8420,16740,29286,14627,16739,8385,4193,2112,2080,2080,2080,0,0,0,2080,2080,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16547,20707,4227,4227,8420,6307,6274,6307,6307,6275,6274,6274,6306,6274,6274,6307,6307,6307,6307,8355,8387,29286,8355,8355,8355,8355,8355,8355,8355,12580,14660,12548,8355,8387,10468,10468,8388,8388,8388,8388,10468,12548,27141,46057,20900,20900,16739,8386,6274,4161,4193,4160,2080,0,0,2080,2080,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4227,4227,4227,4226,6307,6307,6275,6274,6306,8419,6274,6274,6307,6307,6274,10467,10467,8387,6307,6307,8355,6307,6307,8355,8355,8355,10435,8387,8355,8355,8355,8387,8387,8388,8388,10468,16709,14628,16709,29253,52395,25060,39817,25059,6273,4193,2112,4193,6340,6372,4160,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8387,14660,6275,6307,6307,6307,6307,6307,6307,6307,6307,8355,8355,6307,6307,8355,8355,8355,8355,8387,8387,8387,8388,8388,8388,8388,8355,12547,22981,16708,18788,27172,45990,20867,25060,14626,8386,6273,4193,4258,19476,19343,4193,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8388,6307,10435,14628,12547,10467,20900,46089,16706,12546,8353,4193,4160,2080,4161,8648,6469,2112,0,0,2048,0,2080,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6307,12548,18822,22981,14595,6273,8354,8354,10434,6273,4193,4193,0,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
{0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8357,12521,14670,10467,12579,6306,4193,4193,6273,4160,4160,6241,2048,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}
};

const bool midbar_icon PROGMEM [70][18] = {
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false},
{false,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true},
{false,false,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true},
{false,false,false,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true},
{false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,true,true,true},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,true,true,true},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,true,true,true},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,true,true,true},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,true,true,true},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,true,true,true},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,true,true,true},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,true,true,true},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,true,true,true},
{true,true,true,true,false,false,false,false,false,false,false,false,false,false,false,true,true,true},
{true,true,true,true,true,false,false,false,false,false,false,false,false,false,false,true,true,true},
{false,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true},
{false,false,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true},
{false,false,false,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true},
{false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,true,true,true},
{false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,true,true,true},
{false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,true,true,true},
{false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true},
{true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true},
{true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false,false},
{true,true,false,false,false,false,false,false,false,false,false,false,false,false,false,false,true,true},
{true,true,true,true,true,false,false,false,false,false,false,false,true,true,true,true,true,true},
{true,true,true,true,true,true,true,false,true,true,true,true,true,true,true,true,true,true},
{false,false,true,true,true,true,true,true,true,true,true,true,true,true,true,true,false,false},
{false,false,false,false,true,true,true,true,true,true,true,true,false,false,false,false,false,false},
{false,false,true,true,true,true,true,true,false,false,false,false,false,false,false,false,false,false},
{false,true,true,true,true,true,false,false,false,false,false,false,false,false,false,false,false,false},
{false,true,true,true,false,false,false,false,false,false,false,false,false,false,false,true,true,true},
{true,true,true,true,false,false,false,false,false,false,false,false,false,false,false,true,true,true},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,true,true,true},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,true,true,true},
{true,true,true,false,false,false,false,false,false,false,false,false,false,false,false,true,true,true},
{true,true,true,true,false,false,false,false,false,false,false,false,false,false,false,true,true,true},
{true,true,true,true,true,false,false,false,false,false,false,false,false,false,false,true,true,true},
{false,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true},
{false,false,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true},
{false,false,false,true,true,true,true,true,true,true,true,true,true,true,true,true,true,true}
};

void setup(void) {
  oled.begin();
  for (int i = 0; i < 128; i++) {
    for (int j = 0; j < 128; j++) {
      oled.drawPixel(i, j, conv_to_565_img[i][j]);
    }
  }

  for (int i = 0; i < 70; i++) {
    for (int j = 0; j < 18; j++) {
      if (midbar_icon[i][j] == true)
        oled.drawPixel(i, j + 9, 0xD71C);
    }
  }

}
unsigned long previousMillis = 0;

bool sw = false;

void loop() {

  unsigned long currentMillis = millis();

  if (currentMillis - previousMillis >= 2000 && sw == false) {
    previousMillis = currentMillis;
    oled.setTextColor(0x0000);
    oled.setCursor(71, 108);
    oled.print("Press any");
    oled.setCursor(80, 118);
    oled.print("button");
    sw = true;
  }

  if (currentMillis - previousMillis >= 500 && sw == true) {
    previousMillis = currentMillis;
    oled.setTextColor(0xD71C);
    oled.setCursor(71, 108);
    oled.print("Press any");
    oled.setCursor(80, 118);
    oled.print("button");
    sw = false;
  }
}
